@@ -147,6 +147,14 @@ var flagRegistry = []Flag{
 		FlagAddMethod: "StringVar",
 		DefinedOn:     []string{"all"},
 	},
+	{
+		Name:          "sync-remote-cache",
+		Usage:         "Controls how Skaffold manages the remote config cache (see `remote-cache-dir`). One of `always` (default), `missing`, or `never`. `always` syncs remote repositories to latest on access. `missing` only clones remote repositories if they do not exist locally. `never` means the user takes responsibility for updating remote repositories.",
+		Value:         &opts.SyncRemoteCache,
+		DefValue:      "always",
+		FlagAddMethod: "Var",
+		DefinedOn:     []string{"all"},
+	},
 	{
 		Name:          "insecure-registry",
 		Usage:         "Target registries for built images which are not secure",
@@ -551,15 +559,6 @@ var flagRegistry = []Flag{
 		FlagAddMethod: "IntVar",
 		DefinedOn:     []string{"dev", "build", "run", "debug", "deploy"},
 	},
-	{
-		Name:          "v2",
-		Usage:         "Next skaffold config (v2). Use kpt to render/hydrate and deploy manifests.",
-		Value:         &opts.Experimental,
-		DefValue:      false,
-		FlagAddMethod: "BoolVar",
-		DefinedOn:     []string{"apply", "debug", "deploy", "dev", "run"},
-		IsEnum:        true,
-	},
 	{
 		Name:          "digest-source",
 		Usage:         "Set to 'remote' to skip builds and resolve the digest of images by tag from the remote registry. Set to 'local' to build images locally and use digests from built images. Set to 'tag' to use tags directly from the build. Set to 'none' to use tags directly from the Kubernetes manifests.",
