@@ -27,6 +27,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
@@ -92,19 +93,21 @@ func TestDoRun(t *testing.T) {
 	for _, test := range tests {
 		testutil.Run(t, "", func(t *testutil.T) {
 			mockRunner := &mockRunRunner{}
-			t.Override(&createRunner, func(io.Writer, config.SkaffoldOptions) (runner.Runner, []*latestV1.SkaffoldConfig, *runcontext.RunContext, error) {
-				return mockRunner, []*latestV1.SkaffoldConfig{{
-					Pipeline: latestV1.Pipeline{
-						Build: latestV1.BuildConfig{
-							Artifacts: []*latestV1.Artifact{
-								{ImageName: "first"},
-								{ImageName: "second-test"},
-								{ImageName: "test"},
-								{ImageName: "aaabbbccc"},
+			t.Override(&createRunner, func(io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
+				return mockRunner, []util.VersionedConfig{
+					&latestV1.SkaffoldConfig{
+						Pipeline: latestV1.Pipeline{
+							Build: latestV1.BuildConfig{
+								Artifacts: []*latestV1.Artifact{
+									{ImageName: "first"},
+									{ImageName: "second-test"},
+									{ImageName: "test"},
+									{ImageName: "aaabbbccc"},
+								},
 							},
 						},
 					},
-				}}, nil, nil
+				}, nil, nil
 			})
 			t.Override(&opts, config.SkaffoldOptions{
 				TargetImages: []string{"test"},
