@@ -65,7 +65,7 @@ func branchExists(repo, branch string) (bool, error) {
 	if err != nil {
 		return false, err
 	}
-	out, err := util.RunCmdOut(exec.Command(gitProgram, "ls-remote", repo, branch))
+	out, err := util.RunCmdOut(exec.Command(gitProgram, "ls-remote", "--heads", repo, branch))
 	if err != nil {
 		// stdErr contains the error message for os related errors, git permission errors
 		// and if repo doesn't exist
@@ -88,8 +88,7 @@ func getRepoDir(g latestV1.GitInfo) (string, error) {
 		return "", err
 	}
 
-	// UrlEncoding supports '-' as a 63rd character, which can cause dir name issues
-	return base64.StdEncoding.EncodeToString(hasher.Sum(nil))[:32], nil
+	return base64.URLEncoding.EncodeToString(hasher.Sum(nil))[:32], nil
 }
 
 // GetRepoCacheDir returns the directory for the remote git repo cache
@@ -131,7 +130,10 @@ func syncRepo(g latestV1.GitInfo, opts config.SkaffoldOptions) (string, error) {
 	}
 	repoCacheDir := filepath.Join(skaffoldCacheDir, hash)
 	if _, err := os.Stat(repoCacheDir); os.IsNotExist(err) {
-		if _, err := r.Run("clone", g.Repo, hash, "--branch", ref, "--depth", "1"); err != nil {
+		if opts.SyncRemoteCache.CloneDisabled() {
+			return "", SyncDisabledErr(g, repoCacheDir)
+		}
+		if _, err := r.Run("clone", g.Repo, fmt.Sprintf("./%s", hash), "--branch", ref, "--depth", "1"); err != nil {
 			return "", fmt.Errorf("failed to clone repo: %w", err)
 		}
 	} else {
@@ -148,6 +150,11 @@ func syncRepo(g latestV1.GitInfo, opts config.SkaffoldOptions) (string, error) {
 			return repoCacheDir, nil
 		}
 
+		// if sync is turned off via flag `--sync-remote-cache`, then skip fetching latest from remote and resetting the branch.
+		if opts.SyncRemoteCache.FetchDisabled() {
+			return repoCacheDir, nil
+		}
+
 		if _, err = r.Run("fetch", "origin", ref); err != nil {
 			return "", fmt.Errorf("failed to clone repo %s: unable to find any matching refs %s; run 'git clone <REPO>; stat <DIR/SUBDIR>' to verify credentials: %w", g.Repo, ref, err)
 		}
