@@ -55,14 +55,14 @@ func TestDefaultRef(t *testing.T) {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			var f *testutil.FakeCmd
 			if test.masterExists {
-				f = testutil.CmdRunOut("git ls-remote https://github.com/foo.git master", "8be3f718c015a5fe190bebf356079a25afe0ca57  refs/heads/master")
+				f = testutil.CmdRunOut("git ls-remote --heads https://github.com/foo.git master", "8be3f718c015a5fe190bebf356079a25afe0ca57  refs/heads/master")
 			} else {
-				f = testutil.CmdRunOut("git ls-remote https://github.com/foo.git master", "")
+				f = testutil.CmdRunOut("git ls-remote --heads https://github.com/foo.git master", "")
 			}
 			if test.mainExists {
-				f = f.AndRunOut("git ls-remote https://github.com/foo.git main", "8be3f718c015a5fe190bebf356079a25afe0ca58  refs/heads/main")
+				f = f.AndRunOut("git ls-remote --heads https://github.com/foo.git main", "8be3f718c015a5fe190bebf356079a25afe0ca58  refs/heads/main")
 			} else {
-				f = f.AndRunOut("git ls-remote https://github.com/foo.git main", "")
+				f = f.AndRunOut("git ls-remote --heads https://github.com/foo.git main", "")
 			}
 			t.Override(&findGit, func() (string, error) { return "git", nil })
 			t.Override(&util.DefaultExecCommand, f)
@@ -77,6 +77,7 @@ func TestSyncRepo(t *testing.T) {
 		description string
 		g           latestV1.GitInfo
 		cmds        []cmdResponse
+		syncFlag    string
 		existing    bool
 		shouldErr   bool
 		expected    string
@@ -85,18 +86,26 @@ func TestSyncRepo(t *testing.T) {
 			description: "first time repo clone succeeds",
 			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
 			cmds: []cmdResponse{
-				{cmd: "git clone http://github.com/foo.git iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl --branch master --depth 1"},
+				{cmd: "git clone http://github.com/foo.git ./iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl --branch master --depth 1"},
 			},
+			syncFlag: "always",
 			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
 		},
 		{
 			description: "first time repo clone fails",
 			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
 			cmds: []cmdResponse{
-				{cmd: "git clone http://github.com/foo.git iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl --branch master --depth 1", err: errors.New("error")},
+				{cmd: "git clone http://github.com/foo.git ./iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl --branch master --depth 1", err: errors.New("error")},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
+		{
+			description: "first time repo clone with sync off via flag fails",
+			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
+			syncFlag:    "never",
+			shouldErr:   true,
+		},
 		{
 			description: "existing repo update succeeds",
 			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
@@ -108,6 +117,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git diff --name-only --ignore-submodules origin/master..."},
 				{cmd: "git reset --hard origin/master"},
 			},
+			syncFlag: "always",
 			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
 		},
 		{
@@ -117,6 +127,7 @@ func TestSyncRepo(t *testing.T) {
 			cmds: []cmdResponse{
 				{cmd: "git remote -v", err: errors.New("error")},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 		{
@@ -126,6 +137,17 @@ func TestSyncRepo(t *testing.T) {
 			cmds: []cmdResponse{
 				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
 			},
+			syncFlag: "always",
+			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
+		},
+		{
+			description: "existing dirty repo with sync off via flag succeeds",
+			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
+			existing:    true,
+			cmds: []cmdResponse{
+				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
+			},
+			syncFlag: "missing",
 			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
 		},
 		{
@@ -137,6 +159,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git fetch origin master"},
 				{cmd: "git diff --name-only --ignore-submodules HEAD", out: "pkg/foo\npkg/bar"},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 		{
@@ -150,6 +173,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git diff --name-only --ignore-submodules origin/master...", out: "pkg/foo\npkg/bar"},
 				{cmd: "git reset --hard origin/master"},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 		{
@@ -160,6 +184,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
 				{cmd: "git fetch origin master", err: errors.New("error")},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 		{
@@ -172,6 +197,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git diff --name-only --ignore-submodules HEAD"},
 				{cmd: "git diff --name-only --ignore-submodules origin/master...", err: errors.New("error")},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 		{
@@ -183,6 +209,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git fetch origin master"},
 				{cmd: "git diff --name-only --ignore-submodules HEAD", err: errors.New("error")},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 		{
@@ -196,6 +223,7 @@ func TestSyncRepo(t *testing.T) {
 				{cmd: "git diff --name-only --ignore-submodules origin/master..."},
 				{cmd: "git reset --hard origin/master", err: errors.New("error")},
 			},
+			syncFlag:  "always",
 			shouldErr: true,
 		},
 	}
@@ -206,7 +234,9 @@ func TestSyncRepo(t *testing.T) {
 			if test.existing {
 				td.Touch("iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl/.git/")
 			}
-			opts := config.SkaffoldOptions{RepoCacheDir: td.Root()}
+			syncRemote := &config.SyncRemoteCacheOption{}
+			_ = syncRemote.Set(test.syncFlag)
+			opts := config.SkaffoldOptions{RepoCacheDir: td.Root(), SyncRemoteCache: *syncRemote}
 			var f *testutil.FakeCmd
 			for _, v := range test.cmds {
 				if f == nil {
