@@ -22,6 +22,7 @@ import (
 	"strconv"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/docker"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/helm"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/kpt"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/kubectl"
@@ -40,7 +41,8 @@ type deployerCtx struct {
 }
 
 func (d *deployerCtx) GetKubeContext() string {
-	if d.deploy.KubeContext != "" {
+	// if the kubeContext is not overridden by CLI flag or env. variable then use the value provided in config.
+	if d.RunContext.IsDefaultKubeContext() && d.deploy.KubeContext != "" {
 		return d.deploy.KubeContext
 	}
 	return d.RunContext.GetKubeContext()
@@ -62,9 +64,20 @@ func GetDeployer(runCtx *runcontext.RunContext, labeller *label.DefaultLabeller)
 	}
 
 	deployerCfg := runCtx.Deployers()
+	localDeploy := false
+	remoteDeploy := false
 
 	var deployers []deploy.Deployer
 	for _, d := range deployerCfg {
+		if d.DockerDeploy != nil {
+			localDeploy = true
+			d, err := docker.NewDeployer(runCtx, labeller, d.DockerDeploy, runCtx.PortForwardResources())
+			if err != nil {
+				return nil, err
+			}
+			deployers = append(deployers, d)
+		}
+
 		dCtx := &deployerCtx{runCtx, d}
 		if d.HelmDeploy != nil {
 			h, err := helm.NewDeployer(dCtx, labeller, d.HelmDeploy)
@@ -96,6 +109,10 @@ func GetDeployer(runCtx *runcontext.RunContext, labeller *label.DefaultLabeller)
 		}
 	}
 
+	if localDeploy && remoteDeploy {
+		return nil, errors.New("docker deployment not supported alongside cluster deployments")
+	}
+
 	return deploy.NewDeployerMux(deployers, runCtx.IterativeStatusCheck()), nil
 }
 
