@@ -17,6 +17,7 @@ limitations under the License.
 package kubernetes
 
 import (
+	"context"
 	"fmt"
 	"time"
 
@@ -57,7 +58,7 @@ func CreateService(pr *github.PullRequestEvent) (*v1.Service, error) {
 			Selector: selector,
 		},
 	}
-	return client.CoreV1().Services(constants.Namespace).Create(svc)
+	return client.CoreV1().Services(constants.Namespace).Create(context.Background(), svc, metav1.CreateOptions{})
 }
 
 // GetExternalIP polls the service until an external IP is available and returns it
@@ -87,5 +88,5 @@ func getService(svc *v1.Service) (*v1.Service, error) {
 		return nil, fmt.Errorf("getting Kubernetes client: %w", err)
 	}
 
-	return client.CoreV1().Services(svc.Namespace).Get(svc.Name, metav1.GetOptions{})
+	return client.CoreV1().Services(svc.Namespace).Get(context.Background(), svc.Name, metav1.GetOptions{})
 }
